==> zio-aws-athena_3-5.17.104.3-sources.jar: zio/aws/athena/model/ResultConfiguration.scala <==
package zio.aws.athena.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ResultConfiguration(
    outputLocation: Option[String] = None,
    encryptionConfiguration: Option[
      zio.aws.athena.model.EncryptionConfiguration
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.athena.model.ResultConfiguration = {
    import ResultConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.athena.model.ResultConfiguration
      .builder()
      .optionallyWith(outputLocation.map(value => value: java.lang.String))(
        _.outputLocation
      )
      .optionallyWith(
        encryptionConfiguration.map(value => value.buildAwsValue())
      )(_.encryptionConfiguration)
      .build()
  }
  def asReadOnly: zio.aws.athena.model.ResultConfiguration.ReadOnly =
    zio.aws.athena.model.ResultConfiguration.wrap(buildAwsValue())
}
object ResultConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.athena.model.ResultConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.athena.model.ResultConfiguration =
      zio.aws.athena.model.ResultConfiguration(
        outputLocation.map(value => value),
        encryptionConfiguration.map(value => value.asEditable)
      )
    def outputLocation: Option[String]
    def encryptionConfiguration
        : Option[zio.aws.athena.model.EncryptionConfiguration.ReadOnly]
    def getOutputLocation: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("outputLocation", outputLocation)
    def getEncryptionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.athena.model.EncryptionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "encryptionConfiguration",
      encryptionConfiguration
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.athena.model.ResultConfiguration
  ) extends zio.aws.athena.model.ResultConfiguration.ReadOnly {
    override val outputLocation: Option[String] =
      scala.Option(impl.outputLocation()).map(value => value: String)
    override val encryptionConfiguration
        : Option[zio.aws.athena.model.EncryptionConfiguration.ReadOnly] = scala
      .Option(impl.encryptionConfiguration())
      .map(value => zio.aws.athena.model.EncryptionConfiguration.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.athena.model.ResultConfiguration
  ): zio.aws.athena.model.ResultConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-athena_3-5.17.124.3-sources.jar: zio/aws/athena/model/ResultConfiguration.scala <==
package zio.aws.athena.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ResultConfiguration(
    outputLocation: Option[String] = None,
    encryptionConfiguration: Option[
      zio.aws.athena.model.EncryptionConfiguration
    ] = None,
    expectedBucketOwner: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.athena.model.ResultConfiguration = {
    import ResultConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.athena.model.ResultConfiguration
      .builder()
      .optionallyWith(outputLocation.map(value => value: java.lang.String))(
        _.outputLocation
      )
      .optionallyWith(
        encryptionConfiguration.map(value => value.buildAwsValue())
      )(_.encryptionConfiguration)
      .optionallyWith(
        expectedBucketOwner.map(value => value: java.lang.String)
      )(_.expectedBucketOwner)
      .build()
  }
  def asReadOnly: zio.aws.athena.model.ResultConfiguration.ReadOnly =
    zio.aws.athena.model.ResultConfiguration.wrap(buildAwsValue())
}
object ResultConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.athena.model.ResultConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.athena.model.ResultConfiguration =
      zio.aws.athena.model.ResultConfiguration(
        outputLocation.map(value => value),
        encryptionConfiguration.map(value => value.asEditable),
        expectedBucketOwner.map(value => value)
      )
    def outputLocation: Option[String]
    def encryptionConfiguration
        : Option[zio.aws.athena.model.EncryptionConfiguration.ReadOnly]
    def expectedBucketOwner: Option[String]
    def getOutputLocation: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("outputLocation", outputLocation)
    def getEncryptionConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.athena.model.EncryptionConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "encryptionConfiguration",
      encryptionConfiguration
    )
    def getExpectedBucketOwner: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("expectedBucketOwner", expectedBucketOwner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.athena.model.ResultConfiguration
  ) extends zio.aws.athena.model.ResultConfiguration.ReadOnly {
    override val outputLocation: Option[String] =
      scala.Option(impl.outputLocation()).map(value => value: String)
    override val encryptionConfiguration
        : Option[zio.aws.athena.model.EncryptionConfiguration.ReadOnly] = scala
      .Option(impl.encryptionConfiguration())
      .map(value => zio.aws.athena.model.EncryptionConfiguration.wrap(value))
    override val expectedBucketOwner: Option[String] =
      scala.Option(impl.expectedBucketOwner()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.athena.model.ResultConfiguration
  ): zio.aws.athena.model.ResultConfiguration.ReadOnly = new Wrapper(impl)
}
